@@ -6,8 +6,9 @@ use std::process::Command;
 
 fn main() {
     let out_path = PathBuf::from(env::var("OUT_DIR").unwrap());
-    let here_file = PathBuf::from(file!()).canonicalize().unwrap();
+    let here_file = PathBuf::from(env::var("PWD").unwrap()).join(file!());
     let here = here_file.parent().unwrap();
+    println!("{:?}", here);
     Command::new("cp")
         .current_dir(&here)
         .arg("-a")
@@ -39,6 +40,7 @@ fn main() {
         .allowlist_function("^(pfm|PFM|perf|PERF).*")
         .allowlist_var("^(pfm|PFM|perf|PERF).*")
         .rustified_enum("^pfm_.*_t$")
+        .rustified_enum("^perf_.*$")
         .default_macro_constant_type(bindgen::MacroTypeVariation::Signed)
         .header((&header).to_str().unwrap())
         .clang_arg(format!("-I{}", (&include_dir).to_str().unwrap()))
